__all__ = [
    '__author__', '__author_email__', '__copyright__', '__credits__',
    '__license__', '__version__'
]


__author__ = "Jeff Hui"
__author_email__ = "jeff@jeffhui.net"
__copyright__ = "Copyright 2013, Jeff Hui"
__credits__ = ["Jeff Hui", "Patrice Neff", "Andrew Lee"]

__license__ = "MIT"
__version__ = "0.2.8"
